==> vue-sheets-0.5.2.tgz: package/src/components/js/xtable.js <==
import JUI from 'juijs-grid'
import TableComp from 'juijs-grid/src/components/table'
import XTableComp from 'juijs-grid/src/components/xtable'
import props from '../../base/props'
import computed from '../../base/computed'
import watch from '../../base/methods'
import methods from '../../base/methods'

JUI.use(TableComp, XTableComp);

export default {
    name: 'sheets-xtable',
    mixins: [ props, computed, watch, methods ],
    props: {
        scrollWidth: {
            type: Number,
            required: false,
            default: 0
        },
        sortType: {
            type: String,
            required: false,
            default: 'single'
        },
        sortCache: {
            type: Boolean,
            required: false,
            default: false
        },
        xssFilter: {
            type: Boolean,
            required: false,
            default: false
        },
        rowHeight: {
            type: Number,
            required: false,
            default: 26
        },
        pageCount: {
            type: Number,
            required: false,
            default: 100
        }
    },
    computed: {
        tableStyle: function() {
            return {
                width: (typeof(this.tableWidth) == 'string' && this.tableWidth.endsWith('px')) ? parseInt(this.tableWidth) : this.tableWidth
            }
        },
    },
    mounted: function() {
        const self = this;

        const options = {
            fields: this.columnKeys,
            buffer: this.scroll,
            bufferCount: this.pageCount,
            rowHeight: this.rowHeight,
            scrollHeight: this.scrollHeight,
            resize: this.resize,
            sortIndex: this.sortKey,
            sortOrder: this.sortOrder,
            sortCache: this.sortCache,
            xssFilter: this.xssFilter,
            tpl: this.createTplOptions(),
            event: {
                click: function(obj, e) {
                    if(!e) return;
                    self.$emit('click', obj, e);
                },
                rowmenu: function(obj, e) {
                    if(!e) return;
                    self.$emit('rclick', obj, e);
                },
                dblclick: function(obj, e) {
                    if(!e) return;
                    self.$emit('dblclick', obj, e);
                },
                sort: function(obj, e) {
                    if(!e) return;
                    self.setSortEffect(obj);
                    self.$emit('sort', obj, e);
                },
                expand: function(obj, e) {
                    if(!e) return;
                    self.$emit('expand', obj, e);
                },
                expandend: function(obj, e) {
                    if(!e) return;
                    self.$emit('expandend', obj, e);
                },
                sortend: function(obj, e) {
                    if(!e) return;
                    self.$emit('sortend', obj, e);
                },
                msort: function(obj, e) {
                    if(!e) return;
                    self.setMultiSortEffect(obj);
                    self.$emit('sort', obj, e);
                },
                msortend: function() {
                    if(!e) return;
                    self.$emit('sortend');
                }
            }
        };

        // 가로스크롤 사용유무에 따른 옵션 처리
        if(this.scrollWidth > 0) {
            options.width = this.scrollWidth;
            options.scrollWidth = this.tableStyle.width;
        } else {
            options.width = this.tableStyle.width;
        }

        // 정렬 타입에 따른 옵션 처리
        if(this.sortType == 'single') {
            options.sort = this.columnSorts;
        } else {
            options.msort = this.columnSorts;
        }

        // JUI 테이블 컴포넌트 객체 생성
        this.sheet = JUI.create('grid.xtable', this.$el, options);

        // 모든 엘리먼트 스타일 해쉬 적용
        this.replaceScopedHash('.head,.body');

        // JUI 테이블 컴포넌트 템플릿 설정
        const templates = this.createTplOptions();
        for(let key in templates) {
            this.sheet.setTpl(key, templates[key]);
        }

        // 기본 데이터 갱신
        if(this.data != null) {
            this.sheet.update(this.data);
        }
    }
}

==> vue-sheets-0.5.4.tgz: package/src/components/js/xtable.js <==
import JUI from 'juijs-grid'
import TableComp from 'juijs-grid/src/components/table'
import XTableComp from 'juijs-grid/src/components/xtable'
import props from '../../base/props'
import computed from '../../base/computed'
import watch from '../../base/watch'
import methods from '../../base/methods'

JUI.use(TableComp, XTableComp);

export default {
    name: 'sheets-xtable',
    mixins: [ props, computed, watch, methods ],
    props: {
        scrollWidth: {
            type: Number,
            required: false,
            default: 0
        },
        sortType: {
            type: String,
            required: false,
            default: 'single'
        },
        sortCache: {
            type: Boolean,
            required: false,
            default: false
        },
        xssFilter: {
            type: Boolean,
            required: false,
            default: false
        },
        rowHeight: {
            type: Number,
            required: false,
            default: 26
        },
        pageCount: {
            type: Number,
            required: false,
            default: 100
        }
    },
    computed: {
        tableStyle: function() {
            return {
                width: (typeof(this.tableWidth) == 'string' && this.tableWidth.endsWith('px')) ? parseInt(this.tableWidth) : this.tableWidth
            }
        },
    },
    mounted: function() {
        const self = this;

        const options = {
            fields: this.columnKeys,
            buffer: this.scroll,
            bufferCount: this.pageCount,
            rowHeight: this.rowHeight,
            scrollHeight: this.scrollHeight,
            resize: this.resize,
            sortIndex: this.sortKey,
            sortOrder: this.sortOrder,
            sortCache: this.sortCache,
            xssFilter: this.xssFilter,
            tpl: this.createTplOptions(),
            event: {
                click: function(obj, e) {
                    if(!e) return;
                    self.$emit('click', obj, e);
                },
                rowmenu: function(obj, e) {
                    if(!e) return;
                    self.$emit('rclick', obj, e);
                },
                dblclick: function(obj, e) {
                    if(!e) return;
                    self.$emit('dblclick', obj, e);
                },
                sort: function(obj, e) {
                    if(!e) return;
                    self.setSortEffect(obj);
                    self.$emit('sort', obj, e);
                },
                expand: function(obj, e) {
                    if(!e) return;
                    self.$emit('expand', obj, e);
                },
                expandend: function(obj, e) {
                    if(!e) return;
                    self.$emit('expandend', obj, e);
                },
                sortend: function(obj, e) {
                    if(!e) return;
                    self.$emit('sortend', obj, e);
                },
                msort: function(obj, e) {
                    if(!e) return;
                    self.setMultiSortEffect(obj);
                    self.$emit('sort', obj, e);
                },
                msortend: function() {
                    if(!e) return;
                    self.$emit('sortend');
                }
            }
        };

        // 가로스크롤 사용유무에 따른 옵션 처리
        if(this.scrollWidth > 0) {
            options.width = this.scrollWidth;
            options.scrollWidth = this.tableStyle.width;
        } else {
            options.width = this.tableStyle.width;
        }

        // 정렬 타입에 따른 옵션 처리
        if(this.sortType == 'single') {
            options.sort = this.columnSorts;
        } else {
            options.msort = this.columnSorts;
        }

        // JUI 테이블 컴포넌트 객체 생성
        this.sheet = JUI.create('grid.xtable', this.$el, options);

        // 모든 엘리먼트 스타일 해쉬 적용
        this.replaceScopedHash('.head,.body');

        // 기본 데이터 갱신
        if(this.data != null) {
            this.sheet.update(this.data);
        }
    }
}
